<?php

namespace Drupal\ab_age_gate\Controller;

use Drupal\ab_age_gate\AgeGateStatistics;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Response;


/**
 * Class StatisticController.
 */
class StatisticsController extends ControllerBase {

  /** @var \Drupal\ab_age_gate\AgeGateStatistics $statisticService */
  protected $statisticService;

  /** @var \Symfony\Component\HttpFoundation\RequestStack $requestStack */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public function __construct(AgeGateStatistics $statisticService, RequestStack $requestStack) {
    $this->statisticService = $statisticService;
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('ab_age_gate.statistics'),
      $container->get('request_stack'),
    );
  }

  /**
   * Ajax select data callback.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function select() {
    $data = $this->statisticService->selectCurrentData();
    $response = new Response();
    $response->setContent(json_encode($data));
    return $response;
  }

  /**
   * Ajax insert data callback.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   * @throws \Exception
   */
  public function insert() {
    $data = $this->requestStack->getCurrentRequest()->request->all();
    $this->statisticService->insertCurrentData($data['load'], $data['isMobile']);
    $response = new Response();
    return $response;
  }

  /**
   * Ajax update data callback.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   * @throws \Exception
   */
  public function update() {
    $data = $this->requestStack->getCurrentRequest()->request->all();
    $this->statisticService->updateData($data['type'], $data['isMobile']);
    $response = new Response();
    return $response;
  }

}
